import React from 'react';
import Head from 'next/head';
import { FaDownload } from 'react-icons/fa'; // Import download icon

export default function DownloadPage() {
  return (
    <>
      <Head>
        <title>Download Delgor App - Your Ultimate Streaming Experience</title>
        <meta
          name="description"
          content="Download the Delgor app to stream over 30,000+ movies and TV series, including African content, with fast downloads, fewer ads, and no account or credit card required."
        />
        <meta name="keywords" content="Delgor, download app, stream movies, TV series, African movies, fast downloads, no ads, watchlist, no account, no credit card" />
        <meta name="author" content="Delgor" />
        <link rel="canonical" href="https://www.delgor.com/download" />

        {/* Open Graph Meta Tags for Social Media Sharing */}
        <meta property="og:title" content="Download Delgor App - Your Ultimate Streaming Experience" />
        <meta
          property="og:description"
          content="Download the Delgor app to stream over 30,000+ movies and TV series, including African content, with fast downloads, fewer ads, and no account or credit card required."
        />
        <meta property="og:type" content="website" />
        <meta property="og:url" content="https://www.delgor.com/downloadapp" />
        <meta property="og:image" content="/images/ogdelgor.png" /> {/* Replace with an appropriate OG image */}
        <meta property="og:image:alt" content="Delgor App" />

        {/* Twitter Meta Tags */}
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:title" content="Download Delgor App - Your Ultimate Streaming Experience" />
        <meta name="twitter:description" content="Download the Delgor app to stream over 30,000+ movies and TV series, including African content, with fast downloads, fewer ads, and no account or credit card required." />
        <meta name="twitter:image" content="/images/ogdelgor.png" /> {/* Replace with an appropriate OG image */}
        <meta name="twitter:image:alt" content="Delgor App" />
      </Head>
      <div className="flex flex-col items-center justify-center min-h-screen bg-black text-white">
        <div className="text-center p-6 max-w-xl">
          <h1 className="text-4xl font-bold text-red-500 mb-4">
            Download Delgor App
          </h1>
          <p className="text-lg mb-8">
            Experience the ultimate streaming platform with Delgor, where you can:
          </p>
          <ul className="text-left text-lg space-y-2 mb-8">
            <li>• Stream over 30,000+ movies and TV series</li>
            <li>• Access movies from Africa</li>
            <li>• Enjoy unlimited downloads of movies and TV series</li>
            <li>• Benefit from fast download speeds</li>
            <li>• Experience fewer ads</li>
            <li>• Stream without the need for an account</li>
            <li>• Add your favorite movies and TV shows to a watchlist</li>
            <li>• No credit card required</li>
          </ul>
          <a
            href="https://delgor.com/delgor.apk" // Replace with your actual download link
            className="inline-flex items-center px-8 py-4 bg-red-600 hover:bg-red-700 text-white font-semibold rounded-lg transition duration-300 ease-in-out"
            download
          >
            <FaDownload className="mr-2" /> Download Now
          </a>
        </div>
      </div>
    </>
  );
}
